Welcome to the KAT Communication Protocol's documentation!
==========================================================

KATCP is a simple ASCII communication protocol layered on
top of TCP/IP.

It is developed as a part of the `Karoo Array Telescope <http://ska.ac.za/>`_
(KAT) project and used at KAT for the monitoring and control of hardware
devices.

The protocol specification :download:`NRF-KAT7-6.0-IFCE-002-Rev5-1.pdf`
is maintained as an internal memo. The latest version is `Rev5.1`.
The specification source is hosted here:  https://github.com/ska-sa/katcp-guidelines



Contents
========

.. toctree::
   :maxdepth: 2

   releasenotes
   api
   kattypes
   client
   inspecting_client
   resource
   resource_client
   sampling
   server
   tutorial
   how_to_contribute

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
